// This file is part of Substrate.

// Copyright (C) 2022 Parity Technologies (UK) Ltd.
// SPDX-License-Identifier: Apache-2.0

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// 	http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! Autogenerated weights for pallet_lottery
//!
//! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
//! DATE: 2022-12-08, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
//! HOSTNAME: `bm3`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
//! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("dev"), DB CACHE: 1024

// Executed Command:
// /home/benchbot/cargo_target_dir/production/substrate
// benchmark
// pallet
// --steps=50
// --repeat=20
// --extrinsic=*
// --execution=wasm
// --wasm-execution=compiled
// --heap-pages=4096
// --json-file=/var/lib/gitlab-runner/builds/zyw4fam_/0/parity/mirrors/substrate/.git/.artifacts/bench.json
// --pallet=pallet_lottery
// --chain=dev
// --header=./HEADER-APACHE2
// --output=./frame/lottery/src/weights.rs
// --template=./.maintain/frame-weight-template.hbs

#![cfg_attr(rustfmt, rustfmt_skip)]
#![allow(unused_parens)]
#![allow(unused_imports)]

use frame_support::{traits::Get, weights::{Weight, constants::RocksDbWeight}};
use sp_std::marker::PhantomData;

/// Weight functions needed for pallet_lottery.
pub trait WeightInfo {
	fn buy_ticket() -> Weight;
	fn set_calls(n: u32, ) -> Weight;
	fn start_lottery() -> Weight;
	fn stop_repeat() -> Weight;
	fn on_initialize_end() -> Weight;
	fn on_initialize_repeat() -> Weight;
}

/// Weights for pallet_lottery using the Substrate node and recommended hardware.
pub struct SubstrateWeight<T>(PhantomData<T>);
impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
	// Storage: Lottery Lottery (r:1 w:0)
	// Storage: Lottery CallIndices (r:1 w:0)
	// Storage: Lottery TicketsCount (r:1 w:1)
	// Storage: Lottery Participants (r:1 w:1)
	// Storage: Lottery LotteryIndex (r:1 w:0)
	// Storage: System Account (r:1 w:1)
	// Storage: Lottery Tickets (r:0 w:1)
	fn buy_ticket() -> Weight {
		// Minimum execution time: 52_479 nanoseconds.
		Weight::from_ref_time(53_225_000)
			.saturating_add(T::DbWeight::get().reads(6))
			.saturating_add(T::DbWeight::get().writes(4))
	}
	// Storage: Lottery CallIndices (r:0 w:1)
	/// The range of component `n` is `[0, 10]`.
	fn set_calls(n: u32, ) -> Weight {
		// Minimum execution time: 14_433 nanoseconds.
		Weight::from_ref_time(15_660_780)
			// Standard Error: 5_894
			.saturating_add(Weight::from_ref_time(290_482).saturating_mul(n.into()))
			.saturating_add(T::DbWeight::get().writes(1))
	}
	// Storage: Lottery Lottery (r:1 w:1)
	// Storage: Lottery LotteryIndex (r:1 w:1)
	// Storage: System Account (r:1 w:1)
	fn start_lottery() -> Weight {
		// Minimum execution time: 43_683 nanoseconds.
		Weight::from_ref_time(44_580_000)
			.saturating_add(T::DbWeight::get().reads(3))
			.saturating_add(T::DbWeight::get().writes(3))
	}
	// Storage: Lottery Lottery (r:1 w:1)
	fn stop_repeat() -> Weight {
		// Minimum execution time: 10_514 nanoseconds.
		Weight::from_ref_time(10_821_000)
			.saturating_add(T::DbWeight::get().reads(1))
			.saturating_add(T::DbWeight::get().writes(1))
	}
	// Storage: RandomnessCollectiveFlip RandomMaterial (r:1 w:0)
	// Storage: Lottery Lottery (r:1 w:1)
	// Storage: System Account (r:2 w:2)
	// Storage: Lottery TicketsCount (r:1 w:1)
	// Storage: Lottery Tickets (r:1 w:0)
	fn on_initialize_end() -> Weight {
		// Minimum execution time: 60_254 nanoseconds.
		Weight::from_ref_time(61_924_000)
			.saturating_add(T::DbWeight::get().reads(6))
			.saturating_add(T::DbWeight::get().writes(4))
	}
	// Storage: RandomnessCollectiveFlip RandomMaterial (r:1 w:0)
	// Storage: Lottery Lottery (r:1 w:1)
	// Storage: System Account (r:2 w:2)
	// Storage: Lottery TicketsCount (r:1 w:1)
	// Storage: Lottery Tickets (r:1 w:0)
	// Storage: Lottery LotteryIndex (r:1 w:1)
	fn on_initialize_repeat() -> Weight {
		// Minimum execution time: 61_552 nanoseconds.
		Weight::from_ref_time(62_152_000)
			.saturating_add(T::DbWeight::get().reads(7))
			.saturating_add(T::DbWeight::get().writes(5))
	}
}

// For backwards compatibility and tests
impl WeightInfo for () {
	// Storage: Lottery Lottery (r:1 w:0)
	// Storage: Lottery CallIndices (r:1 w:0)
	// Storage: Lottery TicketsCount (r:1 w:1)
	// Storage: Lottery Participants (r:1 w:1)
	// Storage: Lottery LotteryIndex (r:1 w:0)
	// Storage: System Account (r:1 w:1)
	// Storage: Lottery Tickets (r:0 w:1)
	fn buy_ticket() -> Weight {
		// Minimum execution time: 52_479 nanoseconds.
		Weight::from_ref_time(53_225_000)
			.saturating_add(RocksDbWeight::get().reads(6))
			.saturating_add(RocksDbWeight::get().writes(4))
	}
	// Storage: Lottery CallIndices (r:0 w:1)
	/// The range of component `n` is `[0, 10]`.
	fn set_calls(n: u32, ) -> Weight {
		// Minimum execution time: 14_433 nanoseconds.
		Weight::from_ref_time(15_660_780)
			// Standard Error: 5_894
			.saturating_add(Weight::from_ref_time(290_482).saturating_mul(n.into()))
			.saturating_add(RocksDbWeight::get().writes(1))
	}
	// Storage: Lottery Lottery (r:1 w:1)
	// Storage: Lottery LotteryIndex (r:1 w:1)
	// Storage: System Account (r:1 w:1)
	fn start_lottery() -> Weight {
		// Minimum execution time: 43_683 nanoseconds.
		Weight::from_ref_time(44_580_000)
			.saturating_add(RocksDbWeight::get().reads(3))
			.saturating_add(RocksDbWeight::get().writes(3))
	}
	// Storage: Lottery Lottery (r:1 w:1)
	fn stop_repeat() -> Weight {
		// Minimum execution time: 10_514 nanoseconds.
		Weight::from_ref_time(10_821_000)
			.saturating_add(RocksDbWeight::get().reads(1))
			.saturating_add(RocksDbWeight::get().writes(1))
	}
	// Storage: RandomnessCollectiveFlip RandomMaterial (r:1 w:0)
	// Storage: Lottery Lottery (r:1 w:1)
	// Storage: System Account (r:2 w:2)
	// Storage: Lottery TicketsCount (r:1 w:1)
	// Storage: Lottery Tickets (r:1 w:0)
	fn on_initialize_end() -> Weight {
		// Minimum execution time: 60_254 nanoseconds.
		Weight::from_ref_time(61_924_000)
			.saturating_add(RocksDbWeight::get().reads(6))
			.saturating_add(RocksDbWeight::get().writes(4))
	}
	// Storage: RandomnessCollectiveFlip RandomMaterial (r:1 w:0)
	// Storage: Lottery Lottery (r:1 w:1)
	// Storage: System Account (r:2 w:2)
	// Storage: Lottery TicketsCount (r:1 w:1)
	// Storage: Lottery Tickets (r:1 w:0)
	// Storage: Lottery LotteryIndex (r:1 w:1)
	fn on_initialize_repeat() -> Weight {
		// Minimum execution time: 61_552 nanoseconds.
		Weight::from_ref_time(62_152_000)
			.saturating_add(RocksDbWeight::get().reads(7))
			.saturating_add(RocksDbWeight::get().writes(5))
	}
}
