// This file is part of Substrate.

// Copyright (C) 2022 Parity Technologies (UK) Ltd.
// SPDX-License-Identifier: Apache-2.0

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// 	http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! Autogenerated weights for pallet_message_queue
//!
//! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
//! DATE: 2022-12-08, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
//! HOSTNAME: `bm3`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
//! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("dev"), DB CACHE: 1024

// Executed Command:
// /home/benchbot/cargo_target_dir/production/substrate
// benchmark
// pallet
// --steps=50
// --repeat=20
// --extrinsic=*
// --execution=wasm
// --wasm-execution=compiled
// --heap-pages=4096
// --json-file=/var/lib/gitlab-runner/builds/zyw4fam_/0/parity/mirrors/substrate/.git/.artifacts/bench.json
// --pallet=pallet_message_queue
// --chain=dev
// --header=./HEADER-APACHE2
// --output=./frame/message-queue/src/weights.rs
// --template=./.maintain/frame-weight-template.hbs

#![cfg_attr(rustfmt, rustfmt_skip)]
#![allow(unused_parens)]
#![allow(unused_imports)]

use frame_support::{traits::Get, weights::{Weight, constants::RocksDbWeight}};
use sp_std::marker::PhantomData;

/// Weight functions needed for pallet_message_queue.
pub trait WeightInfo {
	fn ready_ring_knit() -> Weight;
	fn ready_ring_unknit() -> Weight;
	fn service_queue_base() -> Weight;
	fn service_page_base_completion() -> Weight;
	fn service_page_base_no_completion() -> Weight;
	fn service_page_item() -> Weight;
	fn bump_service_head() -> Weight;
	fn reap_page() -> Weight;
	fn execute_overweight_page_removed() -> Weight;
	fn execute_overweight_page_updated() -> Weight;
}

/// Weights for pallet_message_queue using the Substrate node and recommended hardware.
pub struct SubstrateWeight<T>(PhantomData<T>);
impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
	// Storage: MessageQueue ServiceHead (r:1 w:0)
	// Storage: MessageQueue BookStateFor (r:2 w:2)
	fn ready_ring_knit() -> Weight {
		// Minimum execution time: 12_330 nanoseconds.
		Weight::from_ref_time(12_711_000)
			.saturating_add(T::DbWeight::get().reads(3))
			.saturating_add(T::DbWeight::get().writes(2))
	}
	// Storage: MessageQueue BookStateFor (r:2 w:2)
	// Storage: MessageQueue ServiceHead (r:1 w:1)
	fn ready_ring_unknit() -> Weight {
		// Minimum execution time: 12_322 nanoseconds.
		Weight::from_ref_time(12_560_000)
			.saturating_add(T::DbWeight::get().reads(3))
			.saturating_add(T::DbWeight::get().writes(3))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	fn service_queue_base() -> Weight {
		// Minimum execution time: 4_652 nanoseconds.
		Weight::from_ref_time(4_848_000)
			.saturating_add(T::DbWeight::get().reads(1))
			.saturating_add(T::DbWeight::get().writes(1))
	}
	// Storage: MessageQueue Pages (r:1 w:1)
	fn service_page_base_completion() -> Weight {
		// Minimum execution time: 7_115 nanoseconds.
		Weight::from_ref_time(7_407_000)
			.saturating_add(T::DbWeight::get().reads(1))
			.saturating_add(T::DbWeight::get().writes(1))
	}
	// Storage: MessageQueue Pages (r:1 w:1)
	fn service_page_base_no_completion() -> Weight {
		// Minimum execution time: 6_974 nanoseconds.
		Weight::from_ref_time(7_200_000)
			.saturating_add(T::DbWeight::get().reads(1))
			.saturating_add(T::DbWeight::get().writes(1))
	}
	fn service_page_item() -> Weight {
		// Minimum execution time: 79_657 nanoseconds.
		Weight::from_ref_time(80_050_000)
	}
	// Storage: MessageQueue ServiceHead (r:1 w:1)
	// Storage: MessageQueue BookStateFor (r:1 w:0)
	fn bump_service_head() -> Weight {
		// Minimum execution time: 7_598 nanoseconds.
		Weight::from_ref_time(8_118_000)
			.saturating_add(T::DbWeight::get().reads(2))
			.saturating_add(T::DbWeight::get().writes(1))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	// Storage: MessageQueue Pages (r:1 w:1)
	fn reap_page() -> Weight {
		// Minimum execution time: 60_562 nanoseconds.
		Weight::from_ref_time(61_430_000)
			.saturating_add(T::DbWeight::get().reads(2))
			.saturating_add(T::DbWeight::get().writes(2))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	// Storage: MessageQueue Pages (r:1 w:1)
	fn execute_overweight_page_removed() -> Weight {
		// Minimum execution time: 74_582 nanoseconds.
		Weight::from_ref_time(75_445_000)
			.saturating_add(T::DbWeight::get().reads(2))
			.saturating_add(T::DbWeight::get().writes(2))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	// Storage: MessageQueue Pages (r:1 w:1)
	fn execute_overweight_page_updated() -> Weight {
		// Minimum execution time: 87_526 nanoseconds.
		Weight::from_ref_time(88_055_000)
			.saturating_add(T::DbWeight::get().reads(2))
			.saturating_add(T::DbWeight::get().writes(2))
	}
}

// For backwards compatibility and tests
impl WeightInfo for () {
	// Storage: MessageQueue ServiceHead (r:1 w:0)
	// Storage: MessageQueue BookStateFor (r:2 w:2)
	fn ready_ring_knit() -> Weight {
		// Minimum execution time: 12_330 nanoseconds.
		Weight::from_ref_time(12_711_000)
			.saturating_add(RocksDbWeight::get().reads(3))
			.saturating_add(RocksDbWeight::get().writes(2))
	}
	// Storage: MessageQueue BookStateFor (r:2 w:2)
	// Storage: MessageQueue ServiceHead (r:1 w:1)
	fn ready_ring_unknit() -> Weight {
		// Minimum execution time: 12_322 nanoseconds.
		Weight::from_ref_time(12_560_000)
			.saturating_add(RocksDbWeight::get().reads(3))
			.saturating_add(RocksDbWeight::get().writes(3))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	fn service_queue_base() -> Weight {
		// Minimum execution time: 4_652 nanoseconds.
		Weight::from_ref_time(4_848_000)
			.saturating_add(RocksDbWeight::get().reads(1))
			.saturating_add(RocksDbWeight::get().writes(1))
	}
	// Storage: MessageQueue Pages (r:1 w:1)
	fn service_page_base_completion() -> Weight {
		// Minimum execution time: 7_115 nanoseconds.
		Weight::from_ref_time(7_407_000)
			.saturating_add(RocksDbWeight::get().reads(1))
			.saturating_add(RocksDbWeight::get().writes(1))
	}
	// Storage: MessageQueue Pages (r:1 w:1)
	fn service_page_base_no_completion() -> Weight {
		// Minimum execution time: 6_974 nanoseconds.
		Weight::from_ref_time(7_200_000)
			.saturating_add(RocksDbWeight::get().reads(1))
			.saturating_add(RocksDbWeight::get().writes(1))
	}
	fn service_page_item() -> Weight {
		// Minimum execution time: 79_657 nanoseconds.
		Weight::from_ref_time(80_050_000)
	}
	// Storage: MessageQueue ServiceHead (r:1 w:1)
	// Storage: MessageQueue BookStateFor (r:1 w:0)
	fn bump_service_head() -> Weight {
		// Minimum execution time: 7_598 nanoseconds.
		Weight::from_ref_time(8_118_000)
			.saturating_add(RocksDbWeight::get().reads(2))
			.saturating_add(RocksDbWeight::get().writes(1))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	// Storage: MessageQueue Pages (r:1 w:1)
	fn reap_page() -> Weight {
		// Minimum execution time: 60_562 nanoseconds.
		Weight::from_ref_time(61_430_000)
			.saturating_add(RocksDbWeight::get().reads(2))
			.saturating_add(RocksDbWeight::get().writes(2))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	// Storage: MessageQueue Pages (r:1 w:1)
	fn execute_overweight_page_removed() -> Weight {
		// Minimum execution time: 74_582 nanoseconds.
		Weight::from_ref_time(75_445_000)
			.saturating_add(RocksDbWeight::get().reads(2))
			.saturating_add(RocksDbWeight::get().writes(2))
	}
	// Storage: MessageQueue BookStateFor (r:1 w:1)
	// Storage: MessageQueue Pages (r:1 w:1)
	fn execute_overweight_page_updated() -> Weight {
		// Minimum execution time: 87_526 nanoseconds.
		Weight::from_ref_time(88_055_000)
			.saturating_add(RocksDbWeight::get().reads(2))
			.saturating_add(RocksDbWeight::get().writes(2))
	}
}
